Yahoo
-----

Register your OAuth2 app below and enter the resultant client id and secret into admin
    https://developer.yahoo.com/apps/create/

The Redirect URL requires secure URLs, please see the section on HTTPS about how this is handled.

When you register the app within yahoo, ensure you select the following API Permissions

- OpenID Connect Permissions

 - Email

 - Profile

When copying the supplied Client ID and Client Secret, do not include the 4 starting spaces.
